==> plasma-wallpaper-dynamic_3.3.6.orig.tar.gz: plasma5-wallpapers-dynamic-3.3.6/src/plugins/kpackage-integration/dynamicwallpaperpackagestructure.cpp <==
/*
 * SPDX-FileCopyrightText: 2020 Vlad Zahorodnii <vlad.zahorodnii@kde.org>
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 */

#include "dynamicwallpaperpackagestructure.h"

#include <KLocalizedString>

#include <QFileInfo>

DynamicWallpaperPackageStructure::DynamicWallpaperPackageStructure(QObject *parent, const QVariantList &args)
    : KPackage::PackageStructure(parent, args)
{
}

void DynamicWallpaperPackageStructure::initPackage(KPackage::Package *package)
{
    package->addDirectoryDefinition(QByteArrayLiteral("images"),
                                    QStringLiteral("images/"),
                                    i18n("Dynamic wallpaper files"));
    package->setRequired(QByteArrayLiteral("images"), true);
}

void DynamicWallpaperPackageStructure::pathChanged(KPackage::Package *package)
{
    package->removeDefinition(QByteArrayLiteral("dynamic"));

    const QStringList fileFormats { QStringLiteral(".heic"), QStringLiteral(".heif") };

    for (const QString &fileFormat : fileFormats) {
        const QFileInfo fileInfo(package->path() + QLatin1String("contents/images/dynamic") + fileFormat);
        if (!fileInfo.exists())
            continue;
        package->addFileDefinition(QByteArrayLiteral("dynamic"),
                                   QStringLiteral("images/dynamic") + fileFormat,
                                   i18n("Dynamic wallpaper file"));
        package->setRequired(QByteArrayLiteral("dynamic"), true);
        break;
    }
}

K_EXPORT_KPACKAGE_PACKAGE_WITH_JSON(DynamicWallpaperPackageStructure, "dynamicwallpaperpackagestructure.json")

#include "dynamicwallpaperpackagestructure.moc"

==> plasma-wallpaper-dynamic_4.4.1.orig.tar.gz: plasma5-wallpapers-dynamic-4.4.1/src/plugins/kpackage-integration/dynamicwallpaperpackagestructure.cpp <==
/*
 * SPDX-FileCopyrightText: 2020 Vlad Zahorodnii <vlad.zahorodnii@kde.org>
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 */

#include "dynamicwallpaperpackagestructure.h"

#include <KLocalizedString>

#include <QFileInfo>

DynamicWallpaperPackageStructure::DynamicWallpaperPackageStructure(QObject *parent, const QVariantList &args)
    : KPackage::PackageStructure(parent, args)
{
}

void DynamicWallpaperPackageStructure::initPackage(KPackage::Package *package)
{
    package->addDirectoryDefinition(QByteArrayLiteral("images"),
                                    QStringLiteral("images/"),
                                    i18n("Dynamic wallpaper files"));
    package->setRequired(QByteArrayLiteral("images"), true);
}

void DynamicWallpaperPackageStructure::pathChanged(KPackage::Package *package)
{
    package->removeDefinition(QByteArrayLiteral("dynamic"));

    const QStringList fileFormats { QStringLiteral(".avif") };

    for (const QString &fileFormat : fileFormats) {
        const QFileInfo fileInfo(package->path() + QLatin1String("contents/images/dynamic") + fileFormat);
        if (!fileInfo.exists())
            continue;
        package->addFileDefinition(QByteArrayLiteral("dynamic"),
                                   QStringLiteral("images/dynamic") + fileFormat,
                                   i18n("Dynamic wallpaper file"));
        package->setRequired(QByteArrayLiteral("dynamic"), true);
        break;
    }
}

K_EXPORT_KPACKAGE_PACKAGE_WITH_JSON(DynamicWallpaperPackageStructure, "dynamicwallpaperpackagestructure.json")

#include "dynamicwallpaperpackagestructure.moc"
